@@ -9,9 +9,15 @@ from .callback import (
 
 # The AIConfigRuntime class. This is the main class that you will use to run your AIConfig.
 from .Config import AIConfigRuntime
-from .default_parsers.openai import DefaultOpenAIParser, OpenAIInference
+
 
 # Model Parsers
+from .default_parsers.anyscale_endpoint import DefaultAnyscaleEndpointParser
+from .default_parsers.azure import AzureOpenAIParser
+from .default_parsers.claude import ClaudeBedrockModelParser
+from .default_parsers.dalle import DalleImageGenerationParser
+from .default_parsers.gemini import  GeminiModelParser
+from .default_parsers.openai import DefaultOpenAIParser, OpenAIInference
 from .default_parsers.palm import PaLMChatParser, PaLMTextParser
 from .default_parsers.parameterized_model_parser import (
     ParameterizedModelParser,
